@@ -1,22 +1,9 @@
-/* === This file is part of Calamares - <https://github.com/calamares> ===
- * 
+/* === This file is part of Calamares - <https://calamares.io> ===
+ *
  *   SPDX-FileCopyrightText: 2018 Adriaan de Groot <groot@kde.org>
- *
- *   Calamares is free software: you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation, either version 3 of the License, or
- *   (at your option) any later version.
- *
- *   Calamares is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
- *
  *   SPDX-License-Identifier: GPL-3.0-or-later
- *   License-Filename: LICENSE
+ *
+ *   Calamares is Free Software: see the License-Identifier above.
  *
  */
 
@@ -24,7 +11,6 @@
  * This is a test-application that does one GeoIP parse.
  */
 
-#include <iostream>
 
 #include "GeoIPFixed.h"
 #include "GeoIPJSON.h"
@@ -32,6 +18,10 @@
 #include "GeoIPXML.h"
 #endif
 
+#include "utils/Logger.h"
+
+#include <iostream>
+
 using std::cerr;
 using namespace CalamaresUtils::GeoIP;
 
@@ -47,6 +37,9 @@ main( int argc, char** argv )
     QString format( argv[ 1 ] );
     QString selector = argc == 3 ? QString( argv[ 2 ] ) : QString();
 
+    Logger::setupLogLevel(Logger::LOGVERBOSE);
+    cDebug() << "Doing GeoIP interpretation with format=" << format << "selector=" << selector;
+
     Interface* handler = nullptr;
     if ( QStringLiteral( "json" ) == format )
     {
