@@ -1,21 +1,12 @@
-/* === This file is part of Calamares - <https://github.com/calamares> ===
+/* === This file is part of Calamares - <https://calamares.io> ===
  *
- *   Copyright 2014, Aurélien Gâteau <agateau@kde.org>
- *   Copyright 2014-2015, Teo Mrnjavac <teo@kde.org>
- *   Copyright 2018, Adriaan de Groot <groot@kde.org>
+ *   SPDX-FileCopyrightText: 2014 Aurélien Gâteau <agateau@kde.org>
+ *   SPDX-FileCopyrightText: 2014-2015 Teo Mrnjavac <teo@kde.org>
+ *   SPDX-FileCopyrightText: 2018 Adriaan de Groot <groot@kde.org>
+ *   SPDX-License-Identifier: GPL-3.0-or-later
  *
- *   Calamares is free software: you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation, either version 3 of the License, or
- *   (at your option) any later version.
+ *   Calamares is Free Software: see the License-Identifier above.
  *
- *   Calamares is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "ExecutionViewStep.h"
@@ -146,10 +137,24 @@ ExecutionViewStep::onActivate()
 {
     m_slideshow->changeSlideShowState( Slideshow::Start );
 
+    const auto instanceDescriptors = Calamares::Settings::instance()->moduleInstances();
+
     JobQueue* queue = JobQueue::instance();
-    foreach ( const QString& instanceKey, m_jobInstanceKeys )
+    for ( const auto& instanceKey : m_jobInstanceKeys )
     {
+        const auto& moduleDescriptor = Calamares::ModuleManager::instance()->moduleDescriptor( instanceKey );
         Calamares::Module* module = Calamares::ModuleManager::instance()->moduleInstance( instanceKey );
+
+        const auto instanceDescriptor
+            = std::find_if( instanceDescriptors.constBegin(),
+                            instanceDescriptors.constEnd(),
+                            [=]( const Calamares::InstanceDescription& d ) { return d.key() == instanceKey; } );
+        int weight = moduleDescriptor.weight();
+        if ( instanceDescriptor != instanceDescriptors.constEnd() && instanceDescriptor->explicitWeight() )
+        {
+            weight = instanceDescriptor->weight();
+        }
+        weight = qBound( 1, weight, 100 );
         if ( module )
         {
             auto jl = module->jobs();
@@ -160,7 +165,7 @@ ExecutionViewStep::onActivate()
                     j->setEmergency( true );
                 }
             }
-            queue->enqueue( jl );
+            queue->enqueue( weight, jl );
         }
     }
 
@@ -176,7 +181,7 @@ ExecutionViewStep::jobs() const
 
 
 void
-ExecutionViewStep::appendJobModuleInstanceKey( const QString& instanceKey )
+ExecutionViewStep::appendJobModuleInstanceKey( const ModuleSystem::InstanceKey& instanceKey )
 {
     m_jobInstanceKeys.append( instanceKey );
 }
@@ -186,7 +191,10 @@ void
 ExecutionViewStep::updateFromJobQueue( qreal percent, const QString& message )
 {
     m_progressBar->setValue( int( percent * m_progressBar->maximum() ) );
-    m_label->setText( message );
+    if ( !message.isEmpty() )
+    {
+        m_label->setText( message );
+    }
 }
 
 void
