@@ -1,24 +1,16 @@
-/* === This file is part of Calamares - <https://github.com/calamares> ===
+/* === This file is part of Calamares - <https://calamares.io> ===
  *
- *   Copyright 2014-2016, Teo Mrnjavac <teo@kde.org>
- *   Copyright 2017-2018, Adriaan de Groot <groot@kde.org>
+ *   SPDX-FileCopyrightText: 2007 Free Software Foundation, Inc.
+ *   SPDX-FileCopyrightText: 2014-2016 Teo Mrnjavac <teo@kde.org>
+ *   SPDX-FileCopyrightText: 2017-2018 Adriaan de Groot <groot@kde.org>
+ *   SPDX-License-Identifier: GPL-3.0-or-later
  *
  *   Portions from the Manjaro Installation Framework
  *   by Roland Singer <roland@manjaro.org>
  *   Copyright (C) 2007 Free Software Foundation, Inc.
  *
- *   Calamares is free software: you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation, either version 3 of the License, or
- *   (at your option) any later version.
+ *   Calamares is Free Software: see the License-Identifier above.
  *
- *   Calamares is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "KeyboardPage.h"
@@ -43,7 +35,7 @@ class LayoutItem : public QListWidgetItem
 public:
     QString data;
 
-    virtual ~LayoutItem();
+    ~LayoutItem() override;
 };
 
 LayoutItem::~LayoutItem() {}
@@ -84,14 +76,12 @@ KeyboardPage::KeyboardPage( QWidget* parent )
     connect(
         ui->buttonRestore, &QPushButton::clicked, [this] { ui->comboBoxModel->setCurrentIndex( m_defaultIndex ); } );
 
-    connect( ui->comboBoxModel,
-             static_cast< void ( QComboBox::* )( const QString& ) >( &QComboBox::currentIndexChanged ),
-             [this]( const QString& text ) {
-                 QString model = m_models.value( text, "pc105" );
+    connect( ui->comboBoxModel, &QComboBox::currentTextChanged, [this]( const QString& text ) {
+        QString model = m_models.value( text, "pc105" );
 
-                 // Set Xorg keyboard model
-                 QProcess::execute( "setxkbmap", QStringList { "-model", model } );
-             } );
+        // Set Xorg keyboard model
+        QProcess::execute( "setxkbmap", QStringList { "-model", model } );
+    } );
 
     CALAMARES_RETRANSLATE( ui->retranslateUi( this ); )
 }
