@@ -1,25 +1,18 @@
-/* === This file is part of Calamares - <https://github.com/calamares> ===
+/* === This file is part of Calamares - <https://calamares.io> ===
  *
- *   Copyright 2014-2016, Teo Mrnjavac <teo@kde.org>
- *   Copyright 2014, Kevin Kofler <kevin.kofler@chello.at>
+ *   SPDX-FileCopyrightText: 2011 Lennart Poettering
+ *   SPDX-FileCopyrightText: Kay Sievers
+ *   SPDX-FileCopyrightText: 2014-2016 Teo Mrnjavac <teo@kde.org>
+ *   SPDX-FileCopyrightText: 2014 Kevin Kofler <kevin.kofler@chello.at>
+ *   SPDX-License-Identifier: GPL-3.0-or-later
  *
  *   Portions from systemd (localed.c):
  *   Copyright 2011 Lennart Poettering
  *   Copyright 2013 Kay Sievers
  *   (originally under LGPLv2.1+, used under the LGPL to GPL conversion clause)
  *
- *   Calamares is free software: you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation, either version 3 of the License, or
- *   (at your option) any later version.
+ *   Calamares is Free Software: see the License-Identifier above.
  *
- *   Calamares is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "SetKeyboardLayoutJob.h"
@@ -86,16 +79,21 @@ SetKeyboardLayoutJob::findConvertedKeymap( const QString& convertedKeymapPath )
 }
 
 
-QString
-SetKeyboardLayoutJob::findLegacyKeymap() const
+STATICTEST QString
+findLegacyKeymap( const QString& layout, const QString& model, const QString& variant )
 {
-    cDebug() << "Looking for legacy keymap in QRC";
+    cDebug() << "Looking for legacy keymap" << layout << model << variant << "in QRC";
 
     int bestMatching = 0;
     QString name;
 
     QFile file( ":/kbd-model-map" );
-    file.open( QIODevice::ReadOnly | QIODevice::Text );
+    if ( !file.open( QIODevice::ReadOnly | QIODevice::Text ) )
+    {
+        cDebug() << Logger::SubEntry << "Could not read QRC";
+        return QString();
+    }
+
     QTextStream stream( &file );
     while ( !stream.atEnd() )
     {
@@ -116,20 +114,20 @@ SetKeyboardLayoutJob::findLegacyKeymap() const
         // Determine how well matching this entry is
         // We assume here that we have one X11 layout. If the UI changes to
         // allow more than one layout, this should change too.
-        if ( m_layout == mapping[ 1 ] )
+        if ( layout == mapping[ 1 ] )
         // If we got an exact match, this is best
         {
             matching = 10;
         }
         // Look for an entry whose first layout matches ours
-        else if ( mapping[ 1 ].startsWith( m_layout + ',' ) )
+        else if ( mapping[ 1 ].startsWith( layout + ',' ) )
         {
             matching = 5;
         }
 
         if ( matching > 0 )
         {
-            if ( m_model.isEmpty() || m_model == mapping[ 2 ] )
+            if ( model.isEmpty() || model == mapping[ 2 ] )
             {
                 matching++;
             }
@@ -144,7 +142,7 @@ SetKeyboardLayoutJob::findLegacyKeymap() const
                 mappingVariant.remove( 1, 0 );
             }
 
-            if ( m_variant == mappingVariant )
+            if ( variant == mappingVariant )
             {
                 matching++;
             }
@@ -169,6 +167,12 @@ SetKeyboardLayoutJob::findLegacyKeymap() const
     return name;
 }
 
+QString
+SetKeyboardLayoutJob::findLegacyKeymap() const
+{
+    return ::findLegacyKeymap( m_layout, m_model, m_variant );
+}
+
 
 bool
 SetKeyboardLayoutJob::writeVConsoleData( const QString& vconsoleConfPath, const QString& convertedKeymapPath ) const
