@@ -1,19 +1,10 @@
-/* === This file is part of Calamares - <https://github.com/calamares> ===
+/* === This file is part of Calamares - <https://calamares.io> ===
  *
- *   Copyright 2017-2018, Adriaan de Groot <groot@kde.org>
+ *   SPDX-FileCopyrightText: 2017-2018 Adriaan de Groot <groot@kde.org>
+ *   SPDX-License-Identifier: GPL-3.0-or-later
  *
- *   Calamares is free software: you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation, either version 3 of the License, or
- *   (at your option) any later version.
+ *   Calamares is Free Software: see the License-Identifier above.
  *
- *   Calamares is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
  */
 #include "PlasmaLnfViewStep.h"
 
@@ -32,7 +23,7 @@
 #include <KSharedConfig>
 #endif
 
-CALAMARES_PLUGIN_FACTORY_DEFINITION( PlasmaLnfViewStepFactory, registerPlugin<PlasmaLnfViewStep>(); )
+CALAMARES_PLUGIN_FACTORY_DEFINITION( PlasmaLnfViewStepFactory, registerPlugin< PlasmaLnfViewStep >(); )
 
 static QString
 currentPlasmaTheme()
@@ -58,7 +49,9 @@ PlasmaLnfViewStep::PlasmaLnfViewStep( QObject* parent )
 PlasmaLnfViewStep::~PlasmaLnfViewStep()
 {
     if ( m_widget && m_widget->parent() == nullptr )
+    {
         m_widget->deleteLater();
+    }
 }
 
 
@@ -104,7 +97,8 @@ PlasmaLnfViewStep::isAtEnd() const
 }
 
 
-void PlasmaLnfViewStep::onLeave()
+void
+PlasmaLnfViewStep::onLeave()
 {
 }
 
@@ -118,9 +112,13 @@ PlasmaLnfViewStep::jobs() const
     if ( !m_themeId.isEmpty() )
     {
         if ( !m_lnfPath.isEmpty() )
+        {
             l.append( Calamares::job_ptr( new PlasmaLnfJob( m_lnfPath, m_themeId ) ) );
+        }
         else
+        {
             cWarning() << "no lnftool given for plasmalnf module.";
+        }
     }
     return l;
 }
@@ -133,20 +131,25 @@ PlasmaLnfViewStep::setConfigurationMap( const QVariantMap& configurationMap )
     m_widget->setLnfPath( m_lnfPath );
 
     if ( m_lnfPath.isEmpty() )
+    {
         cWarning() << "no lnftool given for plasmalnf module.";
+    }
 
     m_liveUser = CalamaresUtils::getString( configurationMap, "liveuser" );
 
     QString preselect = CalamaresUtils::getString( configurationMap, "preselect" );
     if ( preselect == QStringLiteral( "*" ) )
+    {
         preselect = currentPlasmaTheme();
+    }
     if ( !preselect.isEmpty() )
+    {
         m_widget->setPreselect( preselect );
+    }
 
     bool showAll = CalamaresUtils::getBool( configurationMap, "showAll", false );
 
-    if ( configurationMap.contains( "themes" ) &&
-        configurationMap.value( "themes" ).type() == QVariant::List )
+    if ( configurationMap.contains( "themes" ) && configurationMap.value( "themes" ).type() == QVariant::List )
     {
         ThemeInfoList listedThemes;
         auto themeList = configurationMap.value( "themes" ).toList();
@@ -160,14 +163,20 @@ PlasmaLnfViewStep::setConfigurationMap( const QVariantMap& configurationMap )
                 listedThemes.append( ThemeInfo( iv.value( "theme" ).toString(), iv.value( "image" ).toString() ) );
             }
             else if ( i.type() == QVariant::String )
+            {
                 listedThemes.append( ThemeInfo( i.toString() ) );
+            }
 
         if ( listedThemes.length() == 1 )
+        {
             cWarning() << "only one theme enabled in plasmalnf";
+        }
         m_widget->setEnabledThemes( listedThemes, showAll );
     }
     else
+    {
         m_widget->setEnabledThemesAll();  // All of them
+    }
 }
 
 void
@@ -182,9 +191,9 @@ PlasmaLnfViewStep::themeSelected( const QString& id )
 
     QProcess lnftool;
     if ( !m_liveUser.isEmpty() )
-        lnftool.start( "sudo", {"-E", "-H", "-u", m_liveUser, m_lnfPath, "--resetLayout", "--apply", id} );
+        lnftool.start( "sudo", { "-E", "-H", "-u", m_liveUser, m_lnfPath, "--resetLayout", "--apply", id } );
     else
-        lnftool.start( m_lnfPath, {"--resetLayout", "--apply", id} );
+        lnftool.start( m_lnfPath, { "--resetLayout", "--apply", id } );
 
     if ( !lnftool.waitForStarted( 1000 ) )
     {
@@ -198,7 +207,11 @@ PlasmaLnfViewStep::themeSelected( const QString& id )
     }
 
     if ( ( lnftool.exitCode() == 0 ) && ( lnftool.exitStatus() == QProcess::NormalExit ) )
+    {
         cDebug() << "Plasma look-and-feel applied" << id;
+    }
     else
+    {
         cWarning() << "could not apply look-and-feel" << id;
+    }
 }
