@@ -1,28 +1,19 @@
-/* === This file is part of Calamares - <https://github.com/calamares> ===
+/* === This file is part of Calamares - <https://calamares.io> ===
  *
- *   Copyright 2017-2018, Adriaan de Groot <groot@kde.org>
+ *   SPDX-FileCopyrightText: 2017-2018 Adriaan de Groot <groot@kde.org>
+ *   SPDX-License-Identifier: GPL-3.0-or-later
  *
- *   Calamares is free software: you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation, either version 3 of the License, or
- *   (at your option) any later version.
+ *   Calamares is Free Software: see the License-Identifier above.
  *
- *   Calamares is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "ThemeWidget.h"
 
 #include "ThemeInfo.h"
 
+#include "Branding.h"
 #include "utils/CalamaresUtilsGui.h"
 #include "utils/Logger.h"
-#include "Branding.h"
 
 #include <QDir>
 #include <QFileInfo>
@@ -38,33 +29,41 @@
  * empty screenshot. Returns blank if the path
  * doesn't exist anywhere in the search paths.
  */
-static QString _munge_imagepath( const QString& path )
+static QString
+_munge_imagepath( const QString& path )
 {
     if ( path.isEmpty() )
+    {
         return ":/view-preview.png";
+    }
 
     if ( path.startsWith( '/' ) )
+    {
         return path;
+    }
 
     if ( QFileInfo::exists( path ) )
+    {
         return path;
+    }
 
     QFileInfo fi( QDir( Calamares::Branding::instance()->componentDirectory() ), path );
     if ( fi.exists() )
+    {
         return fi.absoluteFilePath();
+    }
 
     return QString();
 }
 
-ThemeWidget::ThemeWidget(const ThemeInfo& info, QWidget* parent)
+ThemeWidget::ThemeWidget( const ThemeInfo& info, QWidget* parent )
     : QWidget( parent )
     , m_id( info.id )
     , m_check( new QRadioButton( info.name.isEmpty() ? info.id : info.name, parent ) )
     , m_description( new QLabel( info.description, parent ) )
 {
-    const QSize image_size{
-        qMax(12 * CalamaresUtils::defaultFontHeight(), 120),
-        qMax(8 * CalamaresUtils::defaultFontHeight(), 80) };
+    const QSize image_size { qMax( 12 * CalamaresUtils::defaultFontHeight(), 120 ),
+                             qMax( 8 * CalamaresUtils::defaultFontHeight(), 80 ) };
 
     QHBoxLayout* layout = new QHBoxLayout( this );
     this->setLayout( layout );
@@ -99,7 +98,9 @@ void
 ThemeWidget::clicked( bool checked )
 {
     if ( checked )
+    {
         emit themeSelected( m_id );
+    }
 }
 
 QAbstractButton*
@@ -108,7 +109,8 @@ ThemeWidget::button() const
     return m_check;
 }
 
-void ThemeWidget::updateThemeName(const ThemeInfo& info)
+void
+ThemeWidget::updateThemeName( const ThemeInfo& info )
 {
     m_check->setText( info.name );
     m_description->setText( info.description );
